<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class PagesAbout extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pages-about';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pages - About Widget', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'pages' ];
	}

	public function get_keywords() {
		return [ 'About', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_about',
			[
				'label' => esc_html__( 'About Area', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'signature',
			[
				'label'   => esc_html__( 'Signature Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Signature Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Banner Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Banner Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'author_name',
			[
				'label'       => __( 'Author Name', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Author Name', 'bdevs-elementor' ),
				'default'     => __( 'It is Author Name', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'author_position',
			[
				'label'       => __( 'Author Position', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your author position', 'bdevs-elementor' ),
				'default'     => __( 'It is Author Position', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Content', 'bdevs-elementor' ),
				'default'     => __( 'It is Content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'About List', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [			
					[
						'name'        => 'tab_option',
						'label'       => esc_html__( 'Option', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		); 

		$this->add_control(
			'show_signature',
			[
				'label'   => esc_html__( 'Show Signature', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_author_name',
			[
				'label'   => esc_html__( 'Show Author Name', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_author_position',
			[
				'label'   => esc_html__( 'Show Author Position', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		?>

        <section class="about section-padding bg-black">
        	<div class="container">
        		<div class="row">
        			<div class="col-md-5 mb-30 animate-box" data-animate-effect="fadeInUp">
        				<?php if (( '' !== $settings['content'] ) && ( $settings['show_content'] )): ?>
        				<?php echo wp_kses_post($settings['content']); ?>
        				<?php endif; ?>
        				<ul class="list-unstyled about-list mb-30">
        					<?php foreach ( $settings['tabs'] as $item ) : ?>
	        					<li>
	        						<div class="about-list-icon"> <span class="ti-check"></span> </div>
	        						<div class="about-list-text">
	        							<p><?php echo wp_kses_post($item['tab_option']); ?></p>
	        						</div>
	        					</li>
        					<?php endforeach; ?>
        				</ul>
        				<hr class="border-1">
        				<div class="about-bottom"> 
        					<?php if (( '' !== $settings['signature']['url'] ) && ( $settings['show_signature'] )): ?>
        					<img src="<?php echo wp_kses_post($settings['signature']['url']); ?>" alt="" class="image about-signature">
        					<?php endif; ?>
        					<div class="about-name-wrapper">
        						<?php if (( '' !== $settings['author_name'] ) && ( $settings['show_author_name'] )): ?>
        						<div class="about-name"><?php echo wp_kses_post($settings['author_name']); ?></div>
        						<?php endif; ?>
        						<?php if (( '' !== $settings['author_position'] ) && ( $settings['show_author_position'] )): ?>
        						<div class="about-rol"><?php echo wp_kses_post($settings['author_position']); ?></div>
        						<?php endif; ?>
        					</div>
        				</div>
        			</div>
        			<div class="col-md-5 offset-md-2 animate-box" data-animate-effect="fadeInUp">
        				<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
        				<div class="about-img">
        					<div class="img"> <img src="<?php echo wp_kses_post($settings['image']['url']); ?>" class="img-fluid" alt=""> </div>
        				</div>
        				<?php endif; ?>
        			</div>
        		</div>
        	</div>
        </section>

	<?php
	}

}
