<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class PagesProject extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pages-project';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pages - Project Widget', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'pages' ];
	}

	public function get_keywords() {
		return [ 'Project', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_project',
			[
				'label' => esc_html__( 'Project Area', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
            'post_number',
            [
                'label'       => __( 'Post Number', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Post Number', 'bdevs-elementor' ),
                'default'     => __( '9', 'bdevs-elementor' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'post_order',
            [
                'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
                    'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
                ],
                'default'   => 'asc',
            ]
        );

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		); 

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		?>

		<section class="projects2 section-padding bg-black">
			<div class="container">
				<div class="row">
					<?php $i = 0;
					$order = $settings['post_order'];
					$post_number = $settings['post_number'];
					$wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'portfolio', 'order' => $order));

					while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
					$project_cate = get_post_meta(get_the_ID(),'_cmb_project_cate', true);
					$i++;
					?>
						<?php if($i%3==1) { ?>
							<div class="col-12 col-md-4 work-masonry-wrapper-padding">
								<div class="portfolio-item-wrapp">
									<div class="portfolio-item">
										<div class="work-masonry-wrapper">
											<a href="<?php the_permalink();?>" class="work-masonry-item-img-link"> <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="">
												<div class="work-masonry-item-img"></div>
												<div class="work-masonry-item-content">
													<div class="work-masonry-item-category"><?php echo esc_attr($project_cate); ?></div>
													<h4 class="work-masonry-item-title"><?php the_title();?></h4>
												</div>
											</a>
										</div>
									</div>
								</div>
							<?php } elseif($i%3==2) { ?>
								<div class="portfolio-item-wrapp">
									<div class="portfolio-item">
										<div class="work-masonry-wrapper">
											<a href="<?php the_permalink();?>" class="work-masonry-item-img-link"> <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="">
												<div class="work-masonry-item-img"></div>
												<div class="work-masonry-item-content">
													<div class="work-masonry-item-category"><?php echo esc_attr($project_cate); ?></div>
													<h4 class="work-masonry-item-title"><?php the_title();?></h4>
												</div>
											</a>
										</div>
									</div>
								</div>
							<?php } else { ?>
								<div class="portfolio-item-wrapp">
									<div class="portfolio-item">
										<div class="work-masonry-wrapper">
											<a href="<?php the_permalink();?>" class="work-masonry-item-img-link"> <img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt="">
												<div class="work-masonry-item-img"></div>
												<div class="work-masonry-item-content">
													<div class="work-masonry-item-category"><?php echo esc_attr($project_cate); ?></div>
													<h4 class="work-masonry-item-title"><?php the_title();?></h4>
												</div>
											</a>
										</div>
									</div>
								</div>
							</div>
						<?php } ?>
					<?php endwhile; ?>
				</div>
			</div>
		</section>

	<?php
	}

}
